<?php

/**
 * 2007-2021 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2019 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

require_once dirname(__FILE__) . '/bifitkassa.php';
require_once dirname(__FILE__) . '/classes/BK.php';

class BifitFiscalCheck extends ModuleAdminController
{
	public function __construct()
	{
		/**
		 * Module is compliant with bootstrap
		 */
		$this->bootstrap = true;

		parent::__construct();
	}

	public function getThisLink($type = 'BifitFiscalCheck', $id = null)
	{
		$suf = '';
		if ($type == 'order') {
			$type = 'AdminOrders';
			$suf = '&amp;id_order=' . intval($id) . '&amp;vieworder';
		} elseif ($type == 'del') {
			$type = 'BifitFiscalCheck';
			$suf = '&amp;id=' . intval($id) . '&amp;deltransaction=1';
		}

		$link = new LinkCore();
		$newLink =
			$link->getAdminLink($type, true, [], ['viewcustomer' => 1]) . $suf;

		return $newLink;
	}

	public function initContent()
	{
		// Удаление записи
		$id = (int) Tools::getValue('id');
		$deltransaction = (int) Tools::getValue('deltransaction');
		if (
			isset($deltransaction) &&
			$deltransaction == 1 &&
			isset($id) &&
			$id > 0
		) {
			self::delTransaction($id);
			Tools::redirect(self::getThisLink());
			die();
		}

		// Добавление ссылок на просмотр заказа и удаление записи
		$transactions = self::getTransactions();
		foreach ($transactions as $key => $val) {
			$transactions[$key]['order_link'] = self::getThisLink(
				'order',
				$val['order_number']
			);
			$transactions[$key]['del_link'] = self::getThisLink(
				'del',
				$val['id_bifitkassa_reports']
			);
		}

		$this->context->smarty->assign('transactions', $transactions);

		$this->context->controller->addJqueryPlugin('fancybox');
		$this->context->controller->addCSS(
			$this->module->getLocalPath() . '/views/css/style.css'
		);

		$this->content = $this->context->smarty->fetch(
			$this->module->getLocalPath() . '/views/templates/admin/reports.tpl'
		);
		parent::initContent();
	}

	protected function getTransactions()
	{
		return Db::getInstance()->ExecuteS(
			"SELECT * 
			   FROM " .
				_DB_PREFIX_ .
				"bifitkassa_reports
			  ORDER BY id_bifitkassa_reports DESC"
		);
	}

	public function delTransaction($id)
	{
		return Db::getInstance()->delete(
			'bifitkassa_reports',
			'id_bifitkassa_reports = ' . (int) $id,
			1
		);
	}
}